<?php

namespace Litecms\Teammember\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Teammember\Http\Requests\TeammembersRequest;
use Litecms\Teammember\Interfaces\TeammembersRepositoryInterface;
use Litecms\Teammember\Models\Teammembers;

/**
 * Resource controller class for teammembers.
 */
class TeammembersResourceController extends BaseController
{

    /**
     * Initialize teammembers resource controller.
     *
     * @param type TeammembersRepositoryInterface $teammembers
     *
     * @return null
     */
    public function __construct(TeammembersRepositoryInterface $teammembers)
    {
        parent::__construct();
        $this->repository = $teammembers;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Teammember\Repositories\Criteria\TeammembersResourceCriteria::class);
    }

    /**
     * Display a list of teammembers.
     *
     * @return Response
     */
    public function index(TeammembersRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Teammember\Repositories\Presenter\TeammembersPresenter::class)
                ->$function();
        }

        $teammembers = $this->repository->paginate();

        return $this->response->title(trans('teammember::teammembers.names'))
            ->view('teammember::teammembers.index', true)
            ->data(compact('teammembers', 'view'))
            ->output();
    }

    /**
     * Display teammembers.
     *
     * @param Request $request
     * @param Model   $teammembers
     *
     * @return Response
     */
    public function show(TeammembersRequest $request, Teammembers $teammembers)
    {

        if ($teammembers->exists) {
            $view = 'teammember::teammembers.show';
        } else {
            $view = 'teammember::teammembers.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('teammember::teammembers.name'))
            ->data(compact('teammembers'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new teammembers.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TeammembersRequest $request)
    {

        $teammembers = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('teammember::teammembers.name')) 
            ->view('teammember::teammembers.create', true) 
            ->data(compact('teammembers'))
            ->output();
    }

    /**
     * Create new teammembers.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TeammembersRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $teammembers                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('teammember::teammembers.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('teammember/teammembers/' . $teammembers->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/teammember/teammembers'))
                ->redirect();
        }

    }

    /**
     * Show teammembers for editing.
     *
     * @param Request $request
     * @param Model   $teammembers
     *
     * @return Response
     */
    public function edit(TeammembersRequest $request, Teammembers $teammembers)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('teammember::teammembers.name'))
            ->view('teammember::teammembers.edit', true)
            ->data(compact('teammembers'))
            ->output();
    }

    /**
     * Update the teammembers.
     *
     * @param Request $request
     * @param Model   $teammembers
     *
     * @return Response
     */
    public function update(TeammembersRequest $request, Teammembers $teammembers)
    {
        try {
            $attributes = $request->all();

            $teammembers->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('teammember::teammembers.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('teammember/teammembers/' . $teammembers->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('teammember/teammembers/' . $teammembers->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the teammembers.
     *
     * @param Model   $teammembers
     *
     * @return Response
     */
    public function destroy(TeammembersRequest $request, Teammembers $teammembers)
    {
        try {

            $teammembers->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('teammember::teammembers.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('teammember/teammembers/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('teammember/teammembers/' . $teammembers->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple teammembers.
     *
     * @param Model   $teammembers
     *
     * @return Response
     */
    public function delete(TeammembersRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('teammember::teammembers.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('teammember/teammembers'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/teammember/teammembers'))
                ->redirect();
        }

    }

    /**
     * Restore deleted teammembers.
     *
     * @param Model   $teammembers
     *
     * @return Response
     */
    public function restore(TeammembersRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('teammember::teammembers.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/teammember/teammembers'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/teammember/teammembers/'))
                ->redirect();
        }

    }

}
